summaryrefslogtreecommitdiff
path: root/source3/python/py_samr_conv.c
diff options
context:
space:
mode:
authorJeremy Allison <jra@samba.org>2005-07-19 00:59:25 +0000
committerGerald (Jerry) Carter <jerry@samba.org>2007-10-10 11:00:09 -0500
commit263a51cd62815b568d0d2053ee29cdd77428ba31 (patch)
tree3fce70b2ca303d22deb00312638716a0e4b5a7da /source3/python/py_samr_conv.c
parent01822a7e054ed83fa4961498f530ede615ac7c24 (diff)
downloadsamba-263a51cd62815b568d0d2053ee29cdd77428ba31.tar.gz
samba-263a51cd62815b568d0d2053ee29cdd77428ba31.tar.bz2
samba-263a51cd62815b568d0d2053ee29cdd77428ba31.zip
r8564: Sometimes we're too dumb to live... Fix samr calls where we were
using USER_INFO_XX structs and functions where XX was sometimes in hex and sometimes in decimal. Now it's all in decimal (should be no functionality change). Jeremy. (This used to be commit 84651aca04cbcbf50ab2e78333cc9d9e49dd92f5)
Diffstat (limited to 'source3/python/py_samr_conv.c')
-rw-r--r--source3/python/py_samr_conv.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/source3/python/py_samr_conv.c b/source3/python/py_samr_conv.c
index 7523ee7dfc..94bedcf779 100644
--- a/source3/python/py_samr_conv.c
+++ b/source3/python/py_samr_conv.c
@@ -22,22 +22,22 @@
#include "python/py_conv.h"
/*
* Convert between SAM_USER_INFO_10 and Python
*/
-struct pyconv py_SAM_USER_INFO_10[] = {
- { "acb_info", PY_UINT32, offsetof(SAM_USER_INFO_10, acb_info) },
+struct pyconv py_SAM_USER_INFO_16[] = {
+ { "acb_info", PY_UINT32, offsetof(SAM_USER_INFO_16, acb_info) },
{ NULL }
};
-BOOL py_from_SAM_USER_INFO_10(PyObject **dict, SAM_USER_INFO_10 *info)
+BOOL py_from_SAM_USER_INFO_16(PyObject **dict, SAM_USER_INFO_16 *info)
{
- *dict = from_struct(info, py_SAM_USER_INFO_10);
- PyDict_SetItemString(*dict, "level", PyInt_FromLong(0x10));
+ *dict = from_struct(info, py_SAM_USER_INFO_16);
+ PyDict_SetItemString(*dict, "level", PyInt_FromLong(16));
return True;
}
-BOOL py_to_SAM_USER_INFO_10(SAM_USER_INFO_10 *info, PyObject *dict)
+BOOL py_to_SAM_USER_INFO_16(SAM_USER_INFO_16 *info, PyObject *dict)
{
PyObject *obj, *dict_copy = PyDict_Copy(dict);
BOOL result = False;
@@ -48,7 +48,7 @@ BOOL py_to_SAM_USER_INFO_10(SAM_USER_INFO_10 *info, PyObject *dict)
PyDict_DelItemString(dict_copy, "level");
- if (!to_struct(info, dict_copy, py_SAM_USER_INFO_10))
+ if (!to_struct(info, dict_copy, py_SAM_USER_INFO_16))
goto done;
result = True;
@@ -22,22 +22,22 @@
#include "python/py_conv.h"
/*
- * Convert between SAM_USER_INFO_10 and Python
+ * Convert between SAM_USER_INFO_16 and Python
*/